import { useDispatch, useSelector } from 'react-redux';
import {
  setGraph,
  ogmaSelector,
  toggleNodeGrouping,
  toggleGeoClustering,
  toggleEdgeGrouping,
  updateNodes,
  toggleGeo
} from './actions';
import data from './data.json';
import Ogma from './ogma.jsx';

function Buttons(props) {
  const ogma = useSelector(ogmaSelector);
  const dispatch = useDispatch();

  if (ogma.geoEnabled) {
    return (
      <span className="top-panel">
        {props.top}
        <button
          disabled={ogma.animating}
          onClick={() => dispatch(toggleGeoClustering())}
        >
          {ogma.geoGroupingEnabled
            ? 'disable geoGrouping'
            : 'enable geoGrouping'}
        </button>
        {props.bottom}
      </span>
    );
  }
  return (
    <span className="top-panel">
      {props.top}
      <button
        disabled={ogma.animating || ogma.nodeGroupingEnabled}
        onClick={() => dispatch(toggleEdgeGrouping())}
      >
        {ogma.edgeGroupingEnabled
          ? 'disable edgeGrouping'
          : 'enable edgeGrouping'}
      </button>
      <button
        disabled={ogma.animating}
        onClick={() => dispatch(toggleNodeGrouping())}
      >
        {ogma.nodeGroupingEnabled
          ? 'disable nodeGrouping'
          : 'enable nodeGrouping'}
      </button>
      {props.bottom}
    </span>
  );
}

function App() {
  const ogma = useSelector(ogmaSelector);

  const dispatch = useDispatch();
  return (
    <div className="App">
      <header></header>
      <Buttons
        top={
          <button
            disabled={ogma.animating}
            onClick={() => dispatch(setGraph(data))}
          >
            Load graph
          </button>
        }
        bottom={
          <button
            disabled={ogma.animating}
            onClick={() => dispatch(toggleGeo())}
          >
            {ogma.geoEnabled ? 'disable geo mode' : 'enable geo mode'}
          </button>
        }
      />
      <span>
        <Ogma
          onTransformationRefreshed={() => dispatch(updateNodes())}
          onTransformationEnabled={() => dispatch(updateNodes())}
          onTransformationDisabled={() => dispatch(updateNodes())}
        />
        <div className="right-panel">
          <ReactJsonTree data={ogma.nodes} />
        </div>
      </span>
    </div>
  );
}

export default App;
